aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/Transforms/Utils/BasicBlockUtils.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Transforms/Utils/BasicBlockUtils.h')
-rw-r--r--include/llvm/Transforms/Utils/BasicBlockUtils.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/include/llvm/Transforms/Utils/BasicBlockUtils.h b/include/llvm/Transforms/Utils/BasicBlockUtils.h
index 281437150f..5279e9620f 100644
--- a/include/llvm/Transforms/Utils/BasicBlockUtils.h
+++ b/include/llvm/Transforms/Utils/BasicBlockUtils.h
@@ -102,10 +102,11 @@ void FindFunctionBackedges(const Function &F,
//
void RemoveSuccessor(TerminatorInst *TI, unsigned SuccNum);
-/// SuccessorNumber - Search for the specified successor of basic block BB and
-/// return its position in the terminator instruction's list of successors.
-/// It is an error to call this with a block that is not a successor.
-unsigned SuccessorNumber(BasicBlock *BB, BasicBlock *Succ);
+/// GetSuccessorNumber - Search for the specified successor of basic block BB
+/// and return its position in the terminator instruction's list of
+/// successors. It is an error to call this with a block that is not a
+/// successor.
+unsigned GetSuccessorNumber(BasicBlock *BB, BasicBlock *Succ);
/// isCriticalEdge - Return true if the specified edge is a critical edge.
/// Critical edges are edges from a block with multiple successors to a block